@@ -15,7 +15,7 @@ from rich.traceback import install
 
 install(show_locals=True)
 
-VERSION = "0.0.12"
+VERSION = "0.0.13"
 
 default_date = dt.date.today().strftime("%Y-%m-%d")
 ELOG_DIR = os.getenv("ELOG_DIR")
@@ -74,7 +74,7 @@ def elog_list(args):
 
     table = Table(style="#8700ff", header_style="bold", box=box.ROUNDED)
     table.add_column("Index", justify="right", style="#ffff00")
-    table.add_column("Timestamp", justify="left", style="#af5f00")
+    table.add_column("Timestamp", justify="left", style="#ff8700")
     table.add_column("Message", justify="left")
 
     for i in range(len(json_data)):
